==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/AzureFirewallNetworkRuleCollectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network rule collection resource.
 * @property action The action type of a rule collection.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
 * @property priority Priority of the network rule collection resource.
 * @property rules Collection of rules used by a network rule collection.
 */
public data class AzureFirewallNetworkRuleCollectionArgs(
    public val action: Output<AzureFirewallRCActionArgs>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val priority: Output<Int>? = null,
    public val rules: Output<List<AzureFirewallNetworkRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs =
        com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority?.applyValue({ args0 -> args0 }))
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureFirewallNetworkRuleCollectionArgs].
 */
@PulumiTagMarker
public class AzureFirewallNetworkRuleCollectionArgsBuilder internal constructor() {
    private var action: Output<AzureFirewallRCActionArgs>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var rules: Output<List<AzureFirewallNetworkRuleArgs>>? = null

    /**
     * @param value The action type of a rule collection.
     */
    @JvmName("ektdlibtotvtseks")
    public suspend fun action(`value`: Output<AzureFirewallRCActionArgs>) {
        this.action = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("xvyvbtchnrfrpqlv")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
     */
    @JvmName("ruwvicuoesmlinur")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Priority of the network rule collection resource.
     */
    @JvmName("pskommknxjkrwluc")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Collection of rules used by a network rule collection.
     */
    @JvmName("hgohiupnvtquajxa")
    public suspend fun rules(`value`: Output<List<AzureFirewallNetworkRuleArgs>>) {
        this.rules = value
    }

    @JvmName("rkcopngbkgaxlhab")
    public suspend fun rules(vararg values: Output<AzureFirewallNetworkRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values Collection of rules used by a network rule collection.
     */
    @JvmName("jvbmlvfhhhctalgn")
    public suspend fun rules(values: List<Output<AzureFirewallNetworkRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value The action type of a rule collection.
     */
    @JvmName("tgojhixgpwjrujii")
    public suspend fun action(`value`: AzureFirewallRCActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument The action type of a rule collection.
     */
    @JvmName("iqjhilbgdvdqvxrf")
    public suspend fun action(argument: suspend AzureFirewallRCActionArgsBuilder.() -> Unit) {
        val toBeMapped = AzureFirewallRCActionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("cmfhgucnvbcwscey")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
     */
    @JvmName("oifemavvtulknfxv")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Priority of the network rule collection resource.
     */
    @JvmName("gctywrphrjguiqyf")
    public suspend fun priority(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value Collection of rules used by a network rule collection.
     */
    @JvmName("qyxokbcpvcelwscr")
    public suspend fun rules(`value`: List<AzureFirewallNetworkRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument Collection of rules used by a network rule collection.
     */
    @JvmName("yhmveqxssqafhoak")
    public suspend fun rules(argument: List<suspend AzureFirewallNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureFirewallNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Collection of rules used by a network rule collection.
     */
    @JvmName("yrikgrfhximheokn")
    public suspend fun rules(
        vararg
        argument: suspend AzureFirewallNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureFirewallNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Collection of rules used by a network rule collection.
     */
    @JvmName("ccsqqluodqfxbrwg")
    public suspend fun rules(argument: suspend AzureFirewallNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AzureFirewallNetworkRuleArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values Collection of rules used by a network rule collection.
     */
    @JvmName("lhwecjpafeqkljak")
    public suspend fun rules(vararg values: AzureFirewallNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): AzureFirewallNetworkRuleCollectionArgs =
        AzureFirewallNetworkRuleCollectionArgs(
            action = action,
            id = id,
            name = name,
            priority = priority,
            rules = rules,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/AzureFirewallNetworkRuleCollectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network rule collection resource.
 * @property action The action type of a rule collection.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
 * @property priority Priority of the network rule collection resource.
 * @property rules Collection of rules used by a network rule collection.
 */
public data class AzureFirewallNetworkRuleCollectionArgs(
    public val action: Output<AzureFirewallRCActionArgs>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val priority: Output<Int>? = null,
    public val rules: Output<List<AzureFirewallNetworkRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs =
        com.pulumi.azurenative.network.inputs.AzureFirewallNetworkRuleCollectionArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority?.applyValue({ args0 -> args0 }))
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureFirewallNetworkRuleCollectionArgs].
 */
@PulumiTagMarker
public class AzureFirewallNetworkRuleCollectionArgsBuilder internal constructor() {
    private var action: Output<AzureFirewallRCActionArgs>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var rules: Output<List<AzureFirewallNetworkRuleArgs>>? = null

    /**
     * @param value The action type of a rule collection.
     */
    @JvmName("sxnhsnefmnxatnid")
    public suspend fun action(`value`: Output<AzureFirewallRCActionArgs>) {
        this.action = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("omxlqllxpfvwpiqw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
     */
    @JvmName("eroltxwnlvwlhjga")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Priority of the network rule collection resource.
     */
    @JvmName("wskfspqrhgkhuihw")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Collection of rules used by a network rule collection.
     */
    @JvmName("blslupqmsudxveno")
    public suspend fun rules(`value`: Output<List<AzureFirewallNetworkRuleArgs>>) {
        this.rules = value
    }

    @JvmName("wflkfgkswwodfbpu")
    public suspend fun rules(vararg values: Output<AzureFirewallNetworkRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values Collection of rules used by a network rule collection.
     */
    @JvmName("cvxaanywrynxjjcv")
    public suspend fun rules(values: List<Output<AzureFirewallNetworkRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value The action type of a rule collection.
     */
    @JvmName("savyqemtifwlbfaj")
    public suspend fun action(`value`: AzureFirewallRCActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument The action type of a rule collection.
     */
    @JvmName("tjsnrobnnvfojafl")
    public suspend fun action(argument: suspend AzureFirewallRCActionArgsBuilder.() -> Unit) {
        val toBeMapped = AzureFirewallRCActionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("rhbinatlxnoupsbw")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within the Azure firewall. This name can be used to access the resource.
     */
    @JvmName("ceomwxifvjnuslqf")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Priority of the network rule collection resource.
     */
    @JvmName("ybpjukkiccmsfdgp")
    public suspend fun priority(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value Collection of rules used by a network rule collection.
     */
    @JvmName("efvtgraonlpyvuce")
    public suspend fun rules(`value`: List<AzureFirewallNetworkRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument Collection of rules used by a network rule collection.
     */
    @JvmName("kyujxswmrdlhtgew")
    public suspend fun rules(argument: List<suspend AzureFirewallNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureFirewallNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Collection of rules used by a network rule collection.
     */
    @JvmName("ihvkthwthojluhpr")
    public suspend fun rules(
        vararg
        argument: suspend AzureFirewallNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureFirewallNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Collection of rules used by a network rule collection.
     */
    @JvmName("uumjjiymumnbvkyr")
    public suspend fun rules(argument: suspend AzureFirewallNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AzureFirewallNetworkRuleArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values Collection of rules used by a network rule collection.
     */
    @JvmName("vopfwbkgjhmneqhx")
    public suspend fun rules(vararg values: AzureFirewallNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): AzureFirewallNetworkRuleCollectionArgs =
        AzureFirewallNetworkRuleCollectionArgs(
            action = action,
            id = id,
            name = name,
            priority = priority,
            rules = rules,
        )
}
